from churros import Client, Query

churros = Client()

# executes mutation { login(username: "lebihae", password: "...") { ...on Error { message }, ...on MutationLoginSuccess { data } }
# on success, sets churros._token to the token
# when churros._token is set, all queries have "Authorization": f"Bearer {self._token}" in headers
await churros.login("lebihae", "correct horse battery staple")

# executes query { me { ... } }
me = await churros.me()

# executes query { me { groups { ... } } }
my_groups = await me.groups()

# this one is paginated, so me.articles() returns an iterator.
# each time we get to the end of loaded articles, we get the page_info { start_cursor, has_next_page } 
# executes query { me { articles { pageInfo { hasNextPage, startCursor }, edges { node { ... }} }}}
# second iteration:
# executes query _q($startCursor: String!) { me { articles(start: $startCursor) { pageInfo { hasNextPage, startCursor }, edges { node { ... }} }}}
# with $startCursor equal to previous query's startCursor
my_articles = await me.articles()


for article in my_articles:
    # executes query _q($id: ID!) { article(id: $id) { group { ... } } }
    group = await article.group()
    print(f"{article.title} posted in {group.name}")

# use this to make less queries to the api
me = await churros.me(include=[churros.me.groups, churros.me.articles])
# this will do `me { ..., groups { ... }, articles { ... } }` 

